Welcome to the eth-abi documentation!
=====================================

The ``eth-abi`` library provides low level utilities for converting python
values to and from solidity's binary ABI format.

For detailed information on ABI types and their encodings, refer to the
`solidity ABI specification
<https://solidity.readthedocs.io/en/latest/abi-spec.html>`_.

Credit
------

Though much of the code has been revised, the ``eth-abi`` library was
originally extracted from the ``pyethereum`` library which was authored by
Vitalik Buterin.

Table of Contents
-----------------

.. toctree::
    :maxdepth: 1

    encoding
    decoding
    registry
    codecs
    nested_dynamic_arrays
    grammar
    tools
    eth_abi_lite
    release_notes


Indices and Tables
------------------

* :ref:`API Glossary <genindex>`
